==> blanco.plugin.resourcebundle_1.3.3-src.zip: blancoResourceBundlePlugin/blanco/main/blanco/plugin/resourcebundle/wizards/AbstractBlancoResourceBundleWizardPage99.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.resourcebundle.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.resourcebundle.BlancoResourceBundlePluginConstants;

/**
 */
public abstract class AbstractBlancoResourceBundleWizardPage99 extends WizardPage {
    /**
     */
    private ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoResourceBundleWizardPage99(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoResourceBundlevOCpxEBU[h̊");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoResourceBundlevOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE).setText("  1.EBU[h ublancoResourceBundleݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ " + BlancoResourceBundlePluginConstants.TARGET_FILENAME + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}

==> blanco.plugin.resourcebundle_1.3.7-src.zip: blancoResourceBundlePlugin/blanco/main/blanco/plugin/resourcebundle/wizards/AbstractBlancoResourceBundleWizardPage99.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.resourcebundle.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.resourcebundle.BlancoResourceBundlePluginConstants;

/**
 */
public abstract class AbstractBlancoResourceBundleWizardPage99 extends WizardPage {
    /**
     */
    protected ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoResourceBundleWizardPage99(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoResourceBundlevOCpxEBU[h̊");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoResourceBundlevOCpxEBU[h Ŋ܂B");
        new Label(container, SWT.NONE).setText("  1.EBU[h ublancoResourceBundleݒt@C GfB^v\܂B");
        new Label(container, SWT.NONE).setText("    ̉ʂ " + BlancoResourceBundlePluginConstants.TARGET_FILENAME + "t@C̃GfB^vOɑ܂B");
        new Label(container, SWT.NONE).setText("  2.ʕ\ɏ]đi߂ĂB");

        setControl(container);
    }
}
